@@ -4,72 +4,72 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
-use overload '""' => sub{ $_[0]->package() }, fallback => 1;
+use overload '""' => sub { $_[0]->package() }, fallback => 1;
 
 use Moose;
 
-has 'depth'         => ( is => 'ro',                                isa => 'Maybe[Num]' );
-has 'package'       => ( is => 'ro', writer => '_set_package',      isa => 'Str' );
-has 'filename'      => ( is => 'ro', writer => '_set_filename',     isa => 'Str' );
-has 'line'          => ( is => 'ro', writer => '_set_line',         isa => 'Num' );
-has 'subroutine'    => ( is => 'ro', writer => '_set_subroutine',   isa => 'Str' );
-has 'hasargs'       => ( is => 'ro', writer => '_set_hasargs',      isa => 'Bool' );
-has 'wantarray'     => ( is => 'ro', writer => '_set_wantarray',    isa => 'Bool' );
-has 'evaltext'      => ( is => 'ro', writer => '_set_evaltext',     isa => 'Str' );
-has 'is_require'    => ( is => 'ro', writer => '_set_is_require',   isa => 'Bool' );
-has 'hints'         => ( is => 'ro', writer => '_set_hints',        isa => 'Num' );
-has 'bitmask'       => ( is => 'ro', writer => '_set_bitmask',      isa => 'Str' );
-has 'hinthash'      => ( is => 'ro', writer => '_set_hinthash',     isa => 'Maybe[HashRef]' );
-has 'args'          => ( is => 'ro', writer => '_set_args',         isa => 'Maybe[ArrayRef]' );
+has 'depth'      => ( is => 'ro', isa    => 'Maybe[Num]' );
+has 'package'    => ( is => 'ro', writer => '_set_package', isa => 'Str' );
+has 'filename'   => ( is => 'ro', writer => '_set_filename', isa => 'Str' );
+has 'line'       => ( is => 'ro', writer => '_set_line', isa => 'Num' );
+has 'subroutine' => ( is => 'ro', writer => '_set_subroutine', isa => 'Str' );
+has 'hasargs'    => ( is => 'ro', writer => '_set_hasargs', isa => 'Bool' );
+has 'wantarray'  => ( is => 'ro', writer => '_set_wantarray', isa => 'Bool' );
+has 'evaltext'   => ( is => 'ro', writer => '_set_evaltext', isa => 'Str' );
+has 'is_require' => ( is => 'ro', writer => '_set_is_require', isa => 'Bool' );
+has 'hints'      => ( is => 'ro', writer => '_set_hints', isa => 'Num' );
+has 'bitmask'    => ( is => 'ro', writer => '_set_bitmask', isa => 'Str' );
+has 'hinthash'   => ( is => 'ro', writer => '_set_hinthash', isa => 'Maybe[HashRef]' );
+has 'args'       => ( is => 'ro', writer => '_set_args', isa => 'Maybe[ArrayRef]' );
 
 around BUILDARGS => sub {
     my $orig  = shift;
     my $class = shift;
 
-    if( @_ == 1 ) {
+    if ( @_ == 1 ) {
         return $class->$orig( depth => $_[0] ) if $_[0] =~ /^\d+$/;
         croak 'Unvalid depth was assigned';
-    }elsif( @_ > 2 ) {
+    }
+    elsif ( @_ > 2 ) {
         croak 'Too many arguments for caller';
-    }elsif( @_ == 2 and not exists $_{depth} ) {
+    }
+    elsif ( @_ == 2 and not exists $_{depth} ) {
         croak 'Unvalid arguments for caller';
-    }else{
+    }
+    else {
         return $class->$orig(@_);
     }
 };
 
 sub BUILD {
-    my $self = shift;
+    my $self  = shift;
     my $depth = $self->depth();
 
-    my (
-        $package, $filename, $line,
-        $subroutine, $hasargs, $wantarray, $evaltext,
-        $is_require, $hints, $bitmask, $hinthash
+    my ($package,  $filename,   $line,  $subroutine, $hasargs, $wantarray,
+        $evaltext, $is_require, $hints, $bitmask,    $hinthash
     );
 
+    if ( defined $depth and $depth =~ /^\d+$/ ) {
 
-    if( defined $depth and $depth =~ /^\d+$/ ) {
         package DB {
             our @args;
             my $i = 1;
             do {
-                ( $package, $filename, $line ) = CORE::caller($i++);
-            } while( $package =~ /^Test::/ or $package =~ /^Caller::Easy/ );
+                ( $package, $filename, $line ) = CORE::caller( $i++ );
+            } while ( $package =~ /^Test::/ or $package =~ /^Caller::Easy/ );
 
-            (
-                undef, undef, undef,
-                $subroutine, $hasargs, $wantarray, $evaltext,
-                $is_require, $hints, $bitmask, $hinthash
+            (   undef,     undef,       undef,  $subroutine, $hasargs, $wantarray,
+                $evaltext, $is_require, $hints, $bitmask,    $hinthash
             ) = CORE::caller( $depth + $i++ );
         }
-    }else{
+    }
+    else {
         my $i = 1;
         do {
-            ( $package, $filename, $line ) = CORE::caller($i++);
-        } while( $package =~ /^Test::/ or $package =~ /^Caller::Easy/ );
+            ( $package, $filename, $line ) = CORE::caller( $i++ );
+        } while ( $package =~ /^Test::/ or $package =~ /^Caller::Easy/ );
 
         $self->_set_package($package)   if $package;
         $self->_set_filename($filename) if $filename;
@@ -79,24 +79,23 @@ sub BUILD {
         return ( $package, $filename, $line );
     }
 
-    $self->_set_package($package)           if $package;
-    $self->_set_filename($filename)         if $filename;
-    $self->_set_line($line)                 if $line;
-    $self->_set_subroutine($subroutine)     if $subroutine;
-    $self->_set_hasargs($hasargs)           if defined $hasargs;
-    $self->_set_wantarray($wantarray)       if defined $wantarray;
-    $self->_set_evaltext($evaltext)         if $evaltext;
-    $self->_set_is_require($is_require)     if defined $is_require;
-    $self->_set_hints($hints)               if $hints;
-    $self->_set_bitmask($bitmask)           if $bitmask;
-    $self->_set_hinthash($hinthash)         if $hinthash;
-    $self->_set_args(\@DB::args);
+    $self->_set_package($package)       if $package;
+    $self->_set_filename($filename)     if $filename;
+    $self->_set_line($line)             if $line;
+    $self->_set_subroutine($subroutine) if $subroutine;
+    $self->_set_hasargs($hasargs)       if defined $hasargs;
+    $self->_set_wantarray($wantarray)   if defined $wantarray;
+    $self->_set_evaltext($evaltext)     if $evaltext;
+    $self->_set_is_require($is_require) if defined $is_require;
+    $self->_set_hints($hints)           if $hints;
+    $self->_set_bitmask($bitmask)       if $bitmask;
+    $self->_set_hinthash($hinthash)     if $hinthash;
+    $self->_set_args( \@DB::args );
 
     return $self unless wantarray;
     return (
-        $package, $filename, $line,
-        $subroutine, $hasargs, $wantarray, $evaltext,
-        $is_require, $hints, $bitmask, $hinthash
+        $package,  $filename,   $line,  $subroutine, $hasargs, $wantarray,
+        $evaltext, $is_require, $hints, $bitmask,    $hinthash
     );
 }
 
@@ -149,7 +148,16 @@ Now you can choise the way you much prefer
 
 Caller::Easy is the easiest way for using functions of C<CORE::caller()>
 
-it produces the easier way to get some info from C<caller()> with no having to care about namespace.
+it produces the easier way to get some info from C<caller()>
+with no having to care about namespace.
+
+=head1 ATTENTION
+
+We can NOT write like below:
+
+ my $subname = caller1->subroutine; # like (caller1)[3];
+
+This would be considered a Bareword.
 
 =head2 Constructor and initialization
 
@@ -254,9 +262,9 @@ One of better implements for using something like this module.
 
 The reason why I reinvent the wheel is that this module has no github repository.
 
-=item L<Safe::Caller|https://github.com/stsc/Safe-Caller>
+=item L<Safe::Caller|https://metacpan.org/pod/Safe::Caller>
 
-The newest implement for using something like this module.
+The newest implement for something like this module.
 
 It has github repository but usage is limited.
 
@@ -264,13 +272,13 @@ It has github repository but usage is limited.
 
 =head1 LICENSE
 
-Copyright (C) Yuki Yoshida.
+Copyright (C) Yuki Yoshida(worthmine).
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Yuki Yoshida E<lt>worthmine@gmail.comE<gt>
+L<Yuki Yoshida(worthmine)|https://github.com/worthmine>
 
 =cut
